@@ -169,14 +169,14 @@ class Emitter(object):
         self.prefixed_colon = self.colon if prefix_colon is None else prefix_colon + self.colon
         # single entry mappings in flow sequence
         self.brace_single_entry_mapping_in_flow_sequence = (
-         brace_single_entry_mapping_in_flow_sequence
-        )  # NOQA
+            brace_single_entry_mapping_in_flow_sequence  # NOQA
+        )
 
         # Formatting details.
         self.canonical = canonical
         self.allow_unicode = allow_unicode
         # set to False to get "\Uxxxxxxxx" for non-basic unicode like emojis
-        self.unicode_supplementary = sys.maxunicode > 0xffff
+        self.unicode_supplementary = sys.maxunicode > 0xFFFF
         self.sequence_dash_offset = block_seq_indent if block_seq_indent else 0
         self.top_level_colon_align = top_level_colon_align
         self.best_sequence_indent = 2
@@ -206,6 +206,8 @@ class Emitter(object):
 
         self.scalar_after_indicator = True  # write a scalar on the same line as `---`
 
+        self.alt_null = 'null'
+
     @property
     def stream(self):
         # type: () -> Any
@@ -799,6 +801,11 @@ class Emitter(object):
         if isinstance(self.event, ScalarEvent):
             if self.style is None:
                 self.style = self.choose_scalar_style()
+                if self.event.value == '' and self.style == "'" and \
+                   tag == 'tag:yaml.org,2002:null' and self.alt_null is not None:
+                    self.event.value = self.alt_null
+                    self.analysis = None
+                    self.style = self.choose_scalar_style()
             if (not self.canonical or tag is None) and (
                 (self.style == "" and self.event.implicit[0])
                 or (self.style != "" and self.event.implicit[1])
